@@ -1,7 +1,7 @@
 package File::Serialize;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: DWIM file serialization/deserialization
-$File::Serialize::VERSION = '1.4.0';
+$File::Serialize::VERSION = '1.5.0';
 use v5.16.0;
 
 use feature 'current_sub';
@@ -24,6 +24,8 @@ use parent 'Exporter::Tiny';
 
 our @EXPORT = qw/ serialize_file deserialize_file transerialize_file /;
 
+our $implicit_transform;
+
 sub _generate_serialize_file {
     my( undef, undef, undef, $global )= @_;
 
@@ -103,8 +105,13 @@ sub _generate_transerialize_file {
         while( my $step = shift @chain) {
             if ( ref $step eq 'CODE' ) {
                 local $_ = $data;
+                if( $implicit_transform  ) {
+                    $step->($data);
+                    $data = $_;
+                }
+                else {
                 $data = $step->($data);
-            }
+            }}
             elsif ( ref $step eq 'ARRAY' ) {
                 die "subranch step can only be the last step of the chain"
                     if @chain;
@@ -179,7 +186,7 @@ File::Serialize - DWIM file serialization/deserialization
 
 =head1 VERSION
 
-version 1.4.0
+version 1.5.0
 
 =head1 SYNOPSIS
 
@@ -242,6 +249,10 @@ L<File::Serialize::Serializer::XML::Simple>
 
 L<File::Serialize::Serializer::JSONY>
 
+=item Markdown
+
+L<File::Serialize::Serializer::Markdown>
+
 =back
 
 =head1 OPTIONS
@@ -370,6 +381,11 @@ and the transformed data is going to be whatever the sub returns.
         => sub($inventory) { +{ pairgrep { $b <= 20 }          %$inventory } }
         => 'inexpensive.json';
 
+If you prefer to have your transform functions modify the structure in-place
+in C<$_> and don't want to have to explicitly return it, you can set
+the global variable C<$File::Serialize::implicit_transform> to C<true>.
+WARNING: this changes the behavior of ALL transforms.
+
 =item \%destinations
 
 A hashref of destination file with their options. The current state of the data will
